Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/is31fl3741_simpletest.py
    :caption: examples/is31fl3741_simpletest.py
    :linenos:

Matrix Examples
---------------

Other examples working on matrix display.

Pillow Examples
---------------

Examples that utilize the Python Imaging Library (Pillow) for use on (Linux)
computers that are using CPython with Adafruit Blinka to support CircuitPython
libraries. CircuitPython does not support PIL/pillow (python imaging library)!
